@@ -9,7 +9,7 @@ use parent 'Class::Accessor';
 use DateTime::Duration;
 use Travel::Status::DE::DBRIS::Location;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 Travel::Routing::DE::DBRIS::Connection::Segment->mk_ro_accessors(
 	qw(
@@ -18,7 +18,7 @@ Travel::Routing::DE::DBRIS::Connection::Segment->mk_ro_accessors(
 	  sched_dep rt_dep dep dep_platform
 	  sched_arr rt_arr arr arr_platform
 	  sched_duration rt_duration duration duration_percent
-	  arr_delay dep_delay delay
+	  arr_delay dep_delay delay feasibility is_unlikely transfer_duration
 	  journey_id
 	  occupancy occupancy_first occupancy_second
 	  is_transfer is_walk walk_name distance_m
@@ -42,6 +42,8 @@ sub new {
 		train_long  => $json->{verkehrsmittel}{langText},
 		direction   => $json->{verkehrsmittel}{richtung},
 		distance_m  => $json->{distanz},
+		feasibility => $json->{anschlussBewertungCode},
+		journey_id  => $json->{journeyId},
 	};
 
 	if ( my $ts = $json->{abfahrtsZeitpunkt} ) {
@@ -134,6 +136,9 @@ sub new {
 
 	for my $message ( @{ $json->{risNotizen} // [] } ) {
 		push( @{ $ref->{messages_ris} }, $message );
+		if ( $message->{key} eq 'text.realtime.journey.missed.connection' ) {
+			$ref->{is_unlikely} = 1;
+		}
 	}
 
 	for my $message ( @{ $json->{priorisierteMeldungen} // [] } ) {
